@@ -282,7 +282,8 @@ bonobo_activation_base_service_debug_shutdown (CORBA_Environment *ev)
 }
 
 static void
-bonobo_activation_existing_set (const BonoboActivationBaseService *base_service, struct SysServer *ss,
+bonobo_activation_existing_set (const BonoboActivationBaseService *base_service,
+                                struct SysServer *ss,
                                 CORBA_Object obj, CORBA_Environment *ev)
 {
 	GSList *link;
@@ -375,13 +376,17 @@ bonobo_activation_internal_service_get_extended (
 
 	g_return_val_if_fail (base_service, CORBA_OBJECT_NIL);
 
+        BONOBO_ACTIVATION_LOCK ();
+
 	for (i = 0; activatable_servers[i].name; i++) {
 		if (!strcmp (base_service->name, activatable_servers[i].name))
 			break;
 	}
 
-	if (!activatable_servers[i].name)
+	if (!activatable_servers[i].name) {
+                BONOBO_ACTIVATION_UNLOCK ();
 		return retval;
+        }
 
 	CORBA_exception_init (&myev);
         CORBA_exception_init (&important_error_ev);
@@ -433,6 +438,8 @@ bonobo_activation_internal_service_get_extended (
         
         CORBA_exception_free (&myev);
 
+        BONOBO_ACTIVATION_LOCK ();
+
 	return retval;
 }
 
@@ -455,22 +462,16 @@ bonobo_activation_service_get (const BonoboActivationBaseService *base_service)
 /*****Implementation of the IOR registration system via plain files ******/
 static int lock_fd = -1;
 
-/*
- * The linc-tmpdir might not be what we expect,
- * requires linc >= 0.5.1
- */
 static const char *
 get_tmpdir (void)
 {
-        static char *tmpdir = NULL;
+        static const char *tmpdir = NULL;
 
         if (!tmpdir)
-                tmpdir = linc_get_tmpdir ();
+                tmpdir = ORBit_get_safe_tmp ();
 
-        if (!tmpdir) {
-                g_warning ("very odd tmpdir problem");
-                tmpdir = g_strdup_printf ("/tmp/orbit-%s", g_get_user_name ());
-        }
+        if (!tmpdir)
+                g_error ("No secure tmpdir found");
 
         return tmpdir;
 }
@@ -667,7 +668,7 @@ local_activator (const BonoboActivationBaseService *base_service,
 
 		return bonobo_activation_server_by_forking (
                         cmd, FALSE, fd_arg, NULL, NULL, base_service->name,
-                        local_re_check_fn, (gpointer)base_service, ev);
+                        TRUE, local_re_check_fn, (gpointer)base_service, ev);
 	}
 
 	return CORBA_OBJECT_NIL;
